"""Top-level package for Rika Firenet."""
from .client import *
from .stove import *
from .const import *
# from .controls import *

__author__ = """Mathieu Tanguy"""
__email__ = 'mathieu@tanguym.eu'
__version__ = '0.0.0'



"""sensors"""
from .coordinator import StoveCoordinator

class StoveSensors(StoveCoordinator):
    """Class getting sensors of stove"""

    def get_state(self):
        """get state"""
        main_state = self._status['sensors']['statusMainState']
        sub_state = self._status['sensors']['statusSubState']
        frost_started = self._status['sensors']['statusFrostStarted']
        result = ["/images/status/Visu_Off.svg", "unknown"]

        if frost_started:
            result = ["/images/status/Visu_Freeze.svg", "frost_protection"]
        result = _MAIN_STATE.get(main_state)
        if main_state == 1:
            if sub_state == 0:
                result = ["/images/status/Visu_Off.svg", "stove_off"]
            elif sub_state in (1, 3):
                result = ["/images/status/Visu_Standby.svg", "standby"]
            elif sub_state == 2:
                result = ["/images/status/Visu_Standby.svg", "external_request"]
        elif main_state == 5:
            if sub_state in (3,4):
                result = ["/images/status/Visu_Clean.svg", "big_clean"]
            else:
                result = ["/images/status/Visu_Clean.svg", "clean"]
        return result
    def get_stove_consumption(self) :
        """Get stove consumption in kg"""
        return self._status['sensors']['parameterFeedRateTotal']

    def get_stove_runtime(self):
        """Runtime"""
        return self._status['sensors']['parameterRuntimePellets']

    def get_stove_thermostat(self) :
        """Get thermostat"""
        return self._status['controls']['targetTemperature']

    def get_room_temperature(self) :
        """Set thermostat"""
        return self._status['sensors']['inputRoomTemperature']

    def is_stove_burning(self) :
        """Set thermostat"""
        main_state = self._status['sensors']['statusMainState']
        if main_state in (4, 5):
            return True
        return False

    def get_stove_flame_temperature(self):
        """Input flame"""
        return float(self._status['sensors']['inputFlameTemperature'])

    def get_stove_operating_mode(self):
        """Operating Mode"""
        return float(self._status['controls']['operatingMode'])

    def get_consumption_before_service(self):
        """Pellet consumption before sevice in kg"""
        return float(self._status['sensors']['parameterFeedRateService'])

    def get_wifi_signal(self):
        """Wifi signal"""
        return float(self._status['sensors']['statusWifiStrength'])

    def is_heating_times_active_for_comfort(self):
        """Heating time for confort"""
        return self._status['controls']['heatingTimesActiveForComfort']

    def is_stove_on(self):
        """Is stove on"""
        return bool(self._status['controls']['onOff'])

    def get_stove_set_back_temperature(self):
        """Back temperature"""
        return float(self._status['controls']['setBackTemperature'])

    def is_stove_convection_fan1_on(self):
        """Convection fan1 state"""
        return bool(self._status['controls']['convectionFan1Active'])

    def is_stove_convection_fan2_on(self):
        """Convection fan2 state"""
        return bool(self._status['controls']['convectionFan2Active'])

    def get_convection_fan1_level(self):
        """Convection fan1 level"""
        return int(self._status['controls']['convectionFan1Level'])

    def get_convection_fan1_area(self):
        """Convection fan1 area"""
        return int(self._status['controls']['convectionFan1Area'])

    def get_convection_fan2_level(self):
        """Convection fan2 level"""
        return int(self._status['controls']['convectionFan2Level'])

    def get_convection_fan2_area(self):
        """Convection fan2 area"""
        return int(self._status['controls']['convectionFan2Area'])

_MAIN_STATE = {
    1: [],
    2: ["/images/status/Visu_Ignition.svg", "ignition_on"],
    3: ["/images/status/Visu_Ignition.svg", "starting_up"],
    4: ["/images/status/Visu_Control.svg", "running"],
    5: [],
    6: ["/images/status/Visu_BurnOff.svg", "burn_off"],
    11: ["/images/status/Visu_SpliLog.svg", "split_log_check"],
    13: ["/images/status/Visu_SpliLog.svg", "split_log_check"],
    14: ["/images/status/Visu_SpliLog.svg", "split_log_check"],
    16: ["/images/status/Visu_SpliLog.svg", "split_log_check"],
    17: ["/images/status/Visu_SpliLog.svg", "split_log_check"],
    20: ["/images/status/Visu_SpliLog.svg", "split_log_mode"],
    21: ["/images/status/Visu_SpliLog.svg", "split_log_mode"],
    50: ["/images/status/Visu_SpliLog.svg", "split_log_check"]
}



"""controls"""
from .coordinator import StoveCoordinator

class StoveControls(StoveCoordinator):
    """Class setting stove control"""

    def turn_on(self):
        """turn on"""
        self.sync_state()
        self._status['controls']['onOff'] = True

        if self._client.set_stove_controls(self._stove_id, self._status['controls']) is True:
            print("Stove has been turned on")
            self.sync_state()
            return True
        return False

    def turn_off(self):
        """turn off"""
        self.sync_state()
        self._status['controls']['onOff'] = False

        if self._client.set_stove_controls(self._stove_id, self._status['controls']) is True:
            print("Stove has been turned off")
            self.sync_state()
            return True
        return False

    def set_stove_thermostat(self, temperature) :
        """Set thermostat"""
        self._status['controls']['targetTemperature'] = str(temperature)
        return True

    def set_confort_power(self, power):
        """Power when using confort mode """
        self._status['controls']['RoomPowerRequest'] = power
        return True

    def set_manual_power(self, percent):
        """Percent power when using manual mode """
        self._status['controls']['heatingPower'] = percent
        return True

    def set_stove_operating_mode(self, mode):
        """Operating Mode"""
        self._status['controls']['operatingMode'] = mode
        return True

    def turn_convection_fan1_on(self):
        """Turn fan1 on"""
        self._status['controls']['convectionFan1Active'] = True

    def turn_convection_fan1_off(self):
        """Turn fan1 off"""
        self._status['controls']['convectionFan1Active'] = False

    def turn_convection_fan2_on(self):
        """Turn fan2 on"""
        self._status['controls']['convectionFan1Active'] = True

    def turn_convection_fan2_off(self):
        """Turn fan2 off"""
        self._status['controls']['convectionFan1Active'] = False



"""Main module."""
# from .client import FirenetClient
from .sensors import StoveSensors
from .controls import StoveControls
# from .coordinator import StoveCoordinator

class Stove(StoveSensors, StoveControls):
    """Class representing a stove"""



"""Xoordinator"""
from .client import FirenetClient

class StoveCoordinator():
    """Class representing a stove coordination"""
    def __init__(self, session, username, password, stove_id):
        self._session = session
        self._username = username
        self._password = password
        self._stove_id = stove_id
        self._client = FirenetClient(session, username, password)
        self._status = None
        self._controls = None

    def connect(self):
        """Connect to stove"""
        if self._client.connect() is True:
            print('Connected to Rika Firenet')
        else:
            raise Exception('Failed to connect with Rika Firenet')
        stoves = self._client.get_stoves_list()
        if stoves:
            for stove in stoves:
                if stove == self._stove_id:
                    print("Stove id found Stove !")
                    return True
            print("Stove id not found !")
            return False
        print("No stove found !")
        return False

    def sync_state(self):
        """Set thermostat"""
        print("Updating stove id: ", self._stove_id)
        self._status = self._client.get_stove_status(self._stove_id)
        return self._status

    def send_controls(self):
        """Operating Mode"""
        if self._client.set_stove_controls(self._stove_id, self._status['controls']) is True:
            return True
        return False
